/*
* player.c - example of player for media volume control.
* This file is part of PetrSU KP Library.
*
* Copyright (C) 2009 - Vanag Pavel. All rights reserved.
*
* PetrSU KP Library is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* PetrSU KP Library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with PetrSU KP Library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA  02110-1301  USA
*/

#include "../SmartSlog_lib/media.h"


int main(int argc, char **argv)
{
    //sslog_ss_init_session();
    sslog_ss_init_session_with_parameters("X", "192.168.112.108", 10010);


	register_ontology();

	if (ss_join(sslog_get_ss_info(), "Player KP") == -1) {
		printf("Can't join to SS\n");
		return 0;
	}

    individual_t *phone = sslog_new_individual(CLASS_MOBILEPHONE);

	sslog_ss_init_individual_with_uuid(phone, "phone1");

	if (phone == NULL) {
		printf("\nError: %s\n", get_error_text());

		ss_leave(sslog_get_ss_info());
		sslog_ss_leave_session_all();
		sslog_repo_clean_all();

		return 0;
	}

    subscription_t *subscription = sslog_new_subscription(false);

	list_t *properties = list_get_new_list();
	list_add_data(PROPERTY_ISCALLING, properties);

	sslog_sbcr_add_individual(subscription, phone, properties);
	

	if (sslog_sbcr_subscribe(subscription) != 0) {
		printf("\nCan't subscribe\n");
		return 0;
	}

	char *old_val = NULL;
	while (true) {
		const prop_val_t *p_val = sslog_get_property(phone, PROPERTY_ISCALLING->name);

		if (p_val != NULL) {
			char *new_val = strdup((char *) p_val->prop_value);
			if (old_val == NULL) old_val = new_val;

			if ((new_val[0]=='0') && (old_val[0]=='1'))
				printf("\n -------- Volume UP\n");
			else if ((new_val[0]=='1') && (old_val[0]=='0'))
				printf("\n -------- Volume DOWN\n");

			old_val = new_val;
			printf("\n");
			fflush(stdout);
		}
	        sslog_sbcr_wait(subscription);
	}

	//  sleep(5);

	ss_leave(sslog_get_ss_info());
    sslog_ss_leave_session_all();
    sslog_repo_clean_all();

	printf("\nKP leave SS...\n");

	return 0;
}
